@@ -10,24 +10,26 @@
 #include "ui_sonnetui.h"
 
 #include "backgroundchecker.h"
+#include "settingsimpl_p.h"
 #include "speller.h"
-#include "settings_p.h"
 
-#include <qprogressdialog.h>
+#include <QProgressDialog>
 
 #include <QDialogButtonBox>
-#include <QStringListModel>
-#include <QPushButton>
 #include <QMessageBox>
+#include <QPushButton>
+#include <QStringListModel>
 
-namespace Sonnet {
-//to initially disable sorting in the suggestions listview
+namespace Sonnet
+{
+// to initially disable sorting in the suggestions listview
 #define NONSORTINGCOLUMN 2
 
 class ReadOnlyStringListModel : public QStringListModel
 {
 public:
-    ReadOnlyStringListModel(QObject *parent) : QStringListModel(parent)
+    explicit ReadOnlyStringListModel(QObject *parent)
+        : QStringListModel(parent)
     {
     }
 
@@ -52,7 +54,7 @@ public:
     QString currentWord;
     int currentPosition;
     QMap<QString, QString> replaceAllMap;
-    bool restart;//used when text is distributed across several qtextedits, eg in KAider
+    bool restart; // used when text is distributed across several qtextedits, eg in KAider
 
     QMap<QString, QString> dictsMap;
 
@@ -101,33 +103,23 @@ Dialog::~Dialog()
 
 void Dialog::initConnections()
 {
-    connect(d->ui.m_addBtn, &QAbstractButton::clicked,
-            this, &Dialog::slotAddWord);
-    connect(d->ui.m_replaceBtn, &QAbstractButton::clicked,
-            this, &Dialog::slotReplaceWord);
-    connect(d->ui.m_replaceAllBtn, &QAbstractButton::clicked,
-            this, &Dialog::slotReplaceAll);
-    connect(d->ui.m_skipBtn, &QAbstractButton::clicked,
-            this, &Dialog::slotSkip);
-    connect(d->ui.m_skipAllBtn, &QAbstractButton::clicked,
-            this, &Dialog::slotSkipAll);
-    connect(d->ui.m_suggestBtn, &QAbstractButton::clicked,
-            this, &Dialog::slotSuggest);
-    connect(d->ui.m_language, SIGNAL(activated(QString)),
-            SLOT(slotChangeLanguage(QString)));
-    connect(d->ui.m_suggestions, SIGNAL(clicked(QModelIndex)),
-            SLOT(slotSelectionChanged(QModelIndex)));
-    connect(d->checker, SIGNAL(misspelling(QString,int)),
-            SLOT(slotMisspelling(QString,int)));
-    connect(d->checker, SIGNAL(done()),
-            SLOT(slotDone()));
-    connect(d->ui.m_suggestions, SIGNAL(doubleClicked(QModelIndex)),
-            SLOT(slotReplaceWord()));
+    connect(d->ui.m_addBtn, &QAbstractButton::clicked, this, &Dialog::slotAddWord);
+    connect(d->ui.m_replaceBtn, &QAbstractButton::clicked, this, &Dialog::slotReplaceWord);
+    connect(d->ui.m_replaceAllBtn, &QAbstractButton::clicked, this, &Dialog::slotReplaceAll);
+    connect(d->ui.m_skipBtn, &QAbstractButton::clicked, this, &Dialog::slotSkip);
+    connect(d->ui.m_skipAllBtn, &QAbstractButton::clicked, this, &Dialog::slotSkipAll);
+    connect(d->ui.m_suggestBtn, &QAbstractButton::clicked, this, &Dialog::slotSuggest);
+    connect(d->ui.m_language, &DictionaryComboBox::textActivated, this, &Dialog::slotChangeLanguage);
+    connect(d->ui.m_suggestions, &QListView::clicked, this, &Dialog::slotSelectionChanged);
+    connect(d->checker, &BackgroundChecker::misspelling, this, &Dialog::slotMisspelling);
+    connect(d->checker, &BackgroundChecker::done, this, &Dialog::slotDone);
+    connect(d->ui.m_suggestions, &QListView::doubleClicked, this, [this](const QModelIndex &) {
+        slotReplaceWord();
+    });
     connect(d->buttonBox, &QDialogButtonBox::accepted, this, &Dialog::slotFinished);
     connect(d->buttonBox, &QDialogButtonBox::rejected, this, &Dialog::slotCancel);
-    connect(d->ui.m_replacement, SIGNAL(returnPressed()), this, SLOT(slotReplaceWord()));
-    connect(d->ui.m_autoCorrect, SIGNAL(clicked()),
-            SLOT(slotAutocorrect()));
+    connect(d->ui.m_replacement, &QLineEdit::returnPressed, this, &Dialog::slotReplaceWord);
+    connect(d->ui.m_autoCorrect, &QPushButton::clicked, this, &Dialog::slotAutocorrect);
     // button use by kword/kpresenter
     // hide by default
     d->ui.m_autoCorrect->hide();
@@ -147,7 +139,7 @@ void Dialog::initGui()
     layout->addWidget(d->wdg);
     layout->addWidget(d->buttonBox);
 
-    //d->ui.m_suggestions->setSorting( NONSORTINGCOLUMN );
+    // d->ui.m_suggestions->setSorting( NONSORTINGCOLUMN );
     fillDictionaryComboBox();
     d->restart = false;
 
@@ -183,7 +175,7 @@ void Dialog::slotAutocorrect()
 {
     setGuiEnabled(false);
     setProgressDialogVisible(true);
-    emit autoCorrect(d->currentWord, d->ui.m_replacement->text());
+    Q_EMIT autoCorrect(d->currentWord, d->ui.m_replacement->text());
     slotReplaceWord();
 }
 
@@ -219,13 +211,13 @@ void Dialog::setProgressDialogVisible(bool b)
 void Dialog::slotFinished()
 {
     setProgressDialogVisible(false);
-    emit stop();
-    //FIXME: should we emit done here?
+    Q_EMIT stop();
+    // FIXME: should we emit done here?
 #if SONNETUI_BUILD_DEPRECATED_SINCE(5, 65)
-    emit done(d->checker->text());
+    Q_EMIT done(d->checker->text());
 #endif
-    emit spellCheckDone(d->checker->text());
-    emit spellCheckStatus(tr("Spell check stopped."));
+    Q_EMIT spellCheckDone(d->checker->text());
+    Q_EMIT spellCheckStatus(tr("Spell check stopped."));
     accept();
 }
 
@@ -234,8 +226,8 @@ void Dialog::slotCancel()
     d->canceled = true;
     d->deleteProgressDialog(false); // this method can be called in response to
     // pressing 'Cancel' on the dialog
-    emit cancel();
-    emit spellCheckStatus(tr("Spell check canceled."));
+    Q_EMIT cancel();
+    Q_EMIT spellCheckStatus(tr("Spell check canceled."));
     reject();
 }
 
@@ -252,7 +244,7 @@ QString Dialog::buffer() const
 void Dialog::setBuffer(const QString &buf)
 {
     d->originalBuffer = buf;
-    //it is possible to change buffer inside slot connected to done() signal
+    // it is possible to change buffer inside slot connected to done() signal
     d->restart = true;
 }
 
@@ -312,13 +304,10 @@ void Dialog::slotReplaceWord()
     setGuiEnabled(false);
     setProgressDialogVisible(true);
     QString replacementText = d->ui.m_replacement->text();
-    emit replace(d->currentWord, d->currentPosition,
-                 replacementText);
+    Q_EMIT replace(d->currentWord, d->currentPosition, replacementText);
 
     if (d->spellCheckContinuedAfterReplacement) {
-        d->checker->replace(d->currentPosition,
-                            d->currentWord,
-                            replacementText);
+        d->checker->replace(d->currentPosition, d->currentWord, replacementText);
         d->checker->continueChecking();
     } else {
         d->checker->stop();
@@ -329,8 +318,7 @@ void Dialog::slotReplaceAll()
 {
     setGuiEnabled(false);
     setProgressDialogVisible(true);
-    d->replaceAllMap.insert(d->currentWord,
-                            d->ui.m_replacement->text());
+    d->replaceAllMap.insert(d->currentWord, d->ui.m_replacement->text());
     slotReplaceWord();
 }
 
@@ -364,7 +352,7 @@ void Dialog::slotChangeLanguage(const QString &lang)
     if (!languageCode.isEmpty()) {
         d->checker->changeLanguage(languageCode);
         slotSuggest();
-        emit languageChanged(languageCode);
+        Q_EMIT languageChanged(languageCode);
     }
 }
 
@@ -382,10 +370,10 @@ void Dialog::slotMisspelling(const QString &word, int start)
 {
     setGuiEnabled(true);
     setProgressDialogVisible(false);
-    emit misspelling(word, start);
-    //NOTE this is HACK I had to introduce because BackgroundChecker lacks 'virtual' marks on methods
-    //this dramatically reduces spellchecking time in Lokalize
-    //as this doesn't fetch suggestions for words that are present in msgid
+    Q_EMIT misspelling(word, start);
+    // NOTE this is HACK I had to introduce because BackgroundChecker lacks 'virtual' marks on methods
+    // this dramatically reduces spellchecking time in Lokalize
+    // as this doesn't fetch suggestions for words that are present in msgid
     if (!updatesEnabled()) {
         return;
     }
@@ -393,7 +381,7 @@ void Dialog::slotMisspelling(const QString &word, int start)
     d->currentWord = word;
     d->currentPosition = start;
     if (d->replaceAllMap.contains(word)) {
-        d->ui.m_replacement->setText(d->replaceAllMap[ word ]);
+        d->ui.m_replacement->setText(d->replaceAllMap[word]);
         slotReplaceWord();
     } else {
         updateDialog(word);
@@ -405,20 +393,19 @@ void Dialog::slotDone()
 {
     d->restart = false;
 #if SONNETUI_BUILD_DEPRECATED_SINCE(5, 65)
-    emit done(d->checker->text());
+    Q_EMIT done(d->checker->text());
 #endif
-    emit spellCheckDone(d->checker->text());
+    Q_EMIT spellCheckDone(d->checker->text());
     if (d->restart) {
         updateDictionaryComboBox();
         d->checker->setText(d->originalBuffer);
         d->restart = false;
     } else {
         setProgressDialogVisible(false);
-        emit spellCheckStatus(tr("Spell check complete."));
+        Q_EMIT spellCheckStatus(tr("Spell check complete."));
         accept();
         if (!d->canceled && d->showCompletionMessageBox) {
-            QMessageBox::information(this, tr("Spell check complete."),
-                                     tr("Check Spelling", "@title:window"));
+            QMessageBox::information(this, tr("Spell check complete."), tr("Check Spelling", "@title:window"));
         }
     }
 }
